@@ -1,5 +1,5 @@
 -- Common.hs: hOpenPGP-tools common functions
--- Copyright © 2012-2021  Clint Adams
+-- Copyright © 2012-2022  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -62,9 +62,9 @@ import qualified Data.ByteString.Lazy as BL
 import Data.Data.Lens (biplate)
 import Data.Text (Text)
 import qualified Data.Text as T
-import Data.Text.Prettyprint.Doc (Doc, (<+>), hardline, pretty)
 import Options.Applicative.Builder (auto, help, hidden, infoOption, long, short)
 import Options.Applicative.Types (Parser, ReadM(..))
+import Prettyprinter (Doc, (<+>), hardline, pretty)
 
 import Codec.Encryption.OpenPGP.KeyInfo (pubkeySize)
 import Control.Error.Util (hush)
