@@ -1,5 +1,5 @@
 -- hkt.hs: hOpenPGP key tool
--- Copyright © 2013-2021  Clint Adams
+-- Copyright © 2013-2022  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -105,9 +105,9 @@ import Options.Applicative.Builder
 import Options.Applicative.Extra (customExecParser, helper, hsubparser)
 import Options.Applicative.Types (Parser)
 
-import Data.Text.Prettyprint.Convert.AnsiWlPprint (toAnsiWlPprint)
-import Data.Text.Prettyprint.Doc ((<+>), fillSep, hardline, list, pretty)
-import Data.Text.Prettyprint.Doc.Render.Text (hPutDoc, putDoc)
+import Prettyprinter.Convert.AnsiWlPprint (toAnsiWlPprint)
+import Prettyprinter.Render.Text (hPutDoc, putDoc)
+import Prettyprinter ((<+>), fillSep, hardline, list, pretty)
 import System.IO (BufferMode(..), Handle, hFlush, hSetBuffering, stderr)
 
 grabMatchingKeysConduit ::
