@@ -1,5 +1,5 @@
 -- hokey.hs: hOpenPGP key tool
--- Copyright © 2013-2021  Clint Adams
+-- Copyright © 2013-2022  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -105,8 +105,8 @@ import System.IO
   , stdout
   )
 
-import Data.Text.Prettyprint.Convert.AnsiWlPprint (toAnsiWlPprint)
-import Data.Text.Prettyprint.Doc
+import Prettyprinter.Convert.AnsiWlPprint (toAnsiWlPprint)
+import Prettyprinter
   ( Doc
   , (<+>)
   , annotate
@@ -118,7 +118,7 @@ import Data.Text.Prettyprint.Doc
   , list
   , pretty
   )
-import qualified Data.Text.Prettyprint.Doc.Render.Terminal as PPA
+import qualified Prettyprinter.Render.Terminal as PPA
 
 linebreak = flatAlt line mempty
 
