@@ -1,5 +1,5 @@
 -- hot.hs: hOpenPGP Tool
--- Copyright © 2012-2021  Clint Adams
+-- Copyright © 2012-2022  Clint Adams
 --
 -- vim: softtabstop=4:shiftwidth=4:expandtab
 --
@@ -54,8 +54,8 @@ import System.IO
   , stdout
   )
 
-import Data.Text.Prettyprint.Convert.AnsiWlPprint (toAnsiWlPprint)
-import Data.Text.Prettyprint.Doc
+import Prettyprinter.Convert.AnsiWlPprint (toAnsiWlPprint)
+import Prettyprinter
   ( Pretty
   , (<+>)
   , group
@@ -64,7 +64,7 @@ import Data.Text.Prettyprint.Doc
   , pretty
   , softline
   )
-import Data.Text.Prettyprint.Doc.Render.Text (hPutDoc)
+import Prettyprinter.Render.Text (hPutDoc)
 import Options.Applicative.Builder
   ( argument
   , command
